@@ -1,4 +1,4 @@
-#' Visualise a matching
+#' Visualize a matching
 #' 
 #' Depict the splits that are matched between two trees using a specified 
 #' [Generalized Robinson&ndash;Foulds](
@@ -23,28 +23,43 @@
 #' @param plainEdges Logical specifying whether to plot edges with a uniform
 #' width and colour (`TRUE`), or whether to draw edge widths according to the
 #' similarity of the associated splits (`FALSE`).
+#' @param edge.cex Character expansion for edge labels.
+#' If `FALSE`, suppress edge labels.
+#' @param value.cex Character expansion for values on edge labels.
+#' If `FALSE`, values are not displayed.
+#' @param edge.frame Character specifying the kind of frame to be printed around
+#' the text of the edge labels.  Choose an abbreviation of `"rect"`, `"circle"`,
+#' or `"none"`.
 #' @param edge.width,edge.color,\dots Additional parameters to send to `Plot()`.
 #' 
-#' @importFrom ape nodelabels edgelabels plot.phylo
-#' @importFrom colorspace qualitative_hcl sequential_hcl
-#' @importFrom graphics par
-#' @importFrom TreeTools as.Splits
+#' @returns `VisualizeMatching()` invisibly returns the matching of splits
+#' between `tree1` and `tree2` (i.e. 
+#' `Func(tree1, tree2, reportMatching = TRUE)`)
 #' 
 #' @examples 
 #' tree1 <- TreeTools::BalancedTree(6)
 #' tree2 <- TreeTools::PectinateTree(6)
 #' 
 #' VisualizeMatching(RobinsonFouldsMatching, tree1, tree2)
-#' VisualizeMatching(SharedPhylogeneticInfo, tree1, tree2, matchZeros = FALSE)
+#' matching <- VisualizeMatching(SharedPhylogeneticInfo, tree1, tree2,
+#'                               matchZeros = FALSE)
+#' attributes(matching)
 #' @template MRS
 #' @encoding UTF-8
+#' @importFrom ape nodelabels edgelabels plot.phylo
+#' @importFrom colorspace qualitative_hcl sequential_hcl
+#' @importFrom graphics par
+#' @importFrom TreeTools as.Splits
 #' @export
-VisualizeMatching <- function(Func, tree1, tree2, setPar = TRUE,
-                              precision = 3L, Plot = plot.phylo,
-                              matchZeros = TRUE, plainEdges = FALSE,
-                              edge.width = 1, edge.color = "black",
-                              ...) {
-  
+VisualizeMatching <- function (Func, tree1, tree2, setPar = TRUE,
+                               precision = 3L, Plot = plot.phylo,
+                               matchZeros = TRUE, plainEdges = FALSE,
+                               edge.cex = par("cex"),
+                               value.cex = edge.cex * 0.8,
+                               edge.frame = "rect",
+                               edge.width = 1, edge.color = "black",
+                               ...) 
+{
   splits1 <- as.Splits(tree1)
   edge1 <- tree1[["edge"]]
   child1 <- edge1[, 2]
@@ -64,8 +79,6 @@ VisualizeMatching <- function(Func, tree1, tree2, setPar = TRUE,
   pairScores <- signif(mapply(function(i, j) scores[i, j],
                               seq_along(pairings), pairings), precision)
   
-  adjNo <- c(0.5, -0.2)
-  adjVal <- c(0.5, 1.1)
   faint <- "#aaaaaa"
   
   if (setPar) {
@@ -73,13 +86,25 @@ VisualizeMatching <- function(Func, tree1, tree2, setPar = TRUE,
     on.exit(par(origPar))
   }
   
-  LabelUnpaired <- function(splitEdges, unpaired) {
+  .LabelEdge <- function(label, edges, frame = "n", ...) {
+    if (edge.cex) {
+      edgelabels(text = label, edge = edges, frame = frame,
+                 cex = edge.cex, adj = c(0.5, -0.2), ...)
+    }
+  }
+  .LabelValue <- function(label, edges, frame = "n", ...) {
+    if (value.cex) {
+      edgelabels(text = label, edge = edges, frame = frame,
+                 cex = value.cex, adj = c(0.5, 1.1), ...)
+    }
+  }
+  
+  .LabelUnpaired <- function(splitEdges, unpaired) {
     if (any(unpaired)) {
-      #edgelabels(text="\u2012", edge=splitEdges[unpaired],
-      edgelabels(text = expression("-"), edge = splitEdges[unpaired],
-                 frame = "n", col = faint, adj = adjNo)
-      edgelabels(text = "0", edge = splitEdges[unpaired],
-                 frame = "n", col = faint, cex = 0.8, adj = adjVal)
+      .LabelEdge(label = expression("-"), edges = splitEdges[unpaired],
+                 frame = "n", col = faint)
+      .LabelValue(label = "0", edges = splitEdges[unpaired],
+                  frame = "n", col = faint)
     }
   }
   
@@ -96,9 +121,12 @@ VisualizeMatching <- function(Func, tree1, tree2, setPar = TRUE,
       if (any(scores < 0)) {
         stop("Negative scores not supported")                                   # nocov
       }
-      if (max(scores) == 0) return(scores)
-      if (min(scores) == max(scores)) return(rep(1L, length(scores)))
-      
+      if (max(scores) == 0) {
+        return(scores)
+      }
+      if (min(scores) == max(scores)) {
+        return(rep(1L, length(scores)))
+      }
       scores / max(scores)
     }
     
@@ -112,7 +140,7 @@ VisualizeMatching <- function(Func, tree1, tree2, setPar = TRUE,
         splitEdges <- vapply(splitNodes, match, table = child, 0)
         got <- rootChildren %in% splitNodes
         if (any(got)) {
-          if(sum(got) != 1) {
+          if (sum(got) != 1) {
             warning("Unexpected polytomy")
           }
           c(score = as.integer(which(splitNodes %in% rootChildren[got])),
@@ -141,7 +169,7 @@ VisualizeMatching <- function(Func, tree1, tree2, setPar = TRUE,
       }
       
       edge.width <- rep(1, nrow(edge))
-      edge.width[se] <-  1 + (10 * ns)
+      edge.width[se] <- 1 + (10 * ns)
       edge.color <- rep("black", nrow(edge))
       edge.color[se] <- edgeColPalette[1 + ceiling(255 * ns)]
       
@@ -159,13 +187,12 @@ VisualizeMatching <- function(Func, tree1, tree2, setPar = TRUE,
   pairedPairScores <- pairScores[paired1]
   pairLabels <- seq_len(sum(paired1))
   if (any(pairLabels)) {
-    edgelabels(text = pairLabels, edge = splitEdges1[paired1],
-               bg = palette, adj = adjNo)
-    edgelabels(text = pairedPairScores, edge = splitEdges1[paired1], 
-               frame = "n", adj = adjVal, cex = 0.8,
-               col = ifelse(pairedPairScores, "black", faint))
+    .LabelEdge(pairLabels, splitEdges1[paired1], frame = edge.frame,
+               bg = palette)
+    .LabelValue(pairedPairScores, splitEdges1[paired1],
+                col = ifelse(pairedPairScores, "black", faint))
   }
-  LabelUnpaired(splitEdges1, !paired1)
+  .LabelUnpaired(splitEdges1, !paired1)
   
   
   paired2 <- seq_along(splitEdges2) %in% pairings[paired1]
@@ -178,14 +205,13 @@ VisualizeMatching <- function(Func, tree1, tree2, setPar = TRUE,
              Normalize(pairedPairScores, na.rm = TRUE), ...)
   }
   if (any(pairLabels)) {
-    edgelabels(text = pairLabels, edge = splitEdges2[pairNames2],
-               bg = palette, adj=adjNo)
-    edgelabels(text = pairedPairScores, edge = splitEdges2[pairNames2], 
-               frame = "n", adj = adjVal, cex = 0.8,
+    .LabelEdge(pairLabels, splitEdges2[pairNames2], frame = edge.frame,
+               bg = palette)
+    .LabelValue(pairedPairScores, splitEdges2[pairNames2],
                col = ifelse(pairedPairScores, "black", faint))
   }
-  LabelUnpaired(splitEdges2, !paired2)
+  .LabelUnpaired(splitEdges2, !paired2)
   
   # Return:
-  invisible()
+  invisible(matching)
 }
