@@ -179,7 +179,8 @@ CalculateTreeDistance <- function(Func, tree1, tree2 = NULL,
                                    tipLabels, nTip = length(tipLabels), ...) {
   
   if (is.na(nTip)) {
-    tipLabels <- union(unlist(tipLabels), unlist(TipLabels(splits2)))
+    tipLabels <- union(unlist(tipLabels, use.names = FALSE),
+                       unlist(TipLabels(splits2), use.names = FALSE))
     splits1 <- as.Splits(splits1, tipLabels = tipLabels, asSplits = TRUE)
     splits2 <- as.Splits(splits2, tipLabels = tipLabels, asSplits = TRUE)
     vapply(splits1, function(s1) {
@@ -475,7 +476,10 @@ NormalizeInfo <- function(unnormalized, tree1, tree2, InfoInTree,
   CombineInfo <- function(tree1Info, tree2Info, Combiner = Combine,
                           pairwise = FALSE) {
     if (length(tree1Info) == 1 || length(tree2Info) == 1 || pairwise) {
-      unlist(.mapply(Combiner, dots = list(tree1Info, tree2Info), NULL))
+      # TODO When requriring R4.0, remove match.fun - which is now part of
+      # .mapply
+      unlist(.mapply(match.fun(Combiner),
+                     dots = list(tree1Info, tree2Info), NULL))
     } else {
       ret <- outer(tree1Info, tree2Info, Combiner)
       if (inherits(unnormalized, "dist")) ret[lower.tri(ret)] else ret
