@@ -1,9 +1,9 @@
 test_that("Day 1985 overflow", {
   bigTree <- PectinateTree(2^14 + 1)
   expect_error(TreeTools::as.ClusterTable(bigTree),
-               "Tree has too many leaves. Contact the 'TreeTools' maintainer.")
+               "Tree has too many leaves. Contact the .TreeTools. maintainer")
   expect_error(RobinsonFoulds(list(bigTree, bigTree)),
-               "Tree has too many leaves. Contact the 'TreeTools' maintainer.")
+               "Tree has too many leaves. Contact the .TreeTools. maintainer")
 })
 
 test_that("Day 1985 examples", {
